@@ -86,7 +86,7 @@
 #define KWAYLANDSERVER_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWAYLANDSERVER_NO_DEPRECATED
-#  define KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54300
+#  define KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54700
 #endif
 #ifdef KWAYLANDSERVER_NO_DEPRECATED_WARNINGS
 #  define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE KWAYLANDSERVER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE 0x54300
+#    define KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE 0x54700
 #  endif
 #endif
 
@@ -133,7 +133,14 @@
 #else
 #  define KWAYLANDSERVER_DEPRECATED_VERSION_5_52(text)
 #endif
+
+#if KWAYLANDSERVER_DEPRECATED_WARNINGS_SINCE >= 0x54500
+#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_69(text) KWAYLANDSERVER_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KWAYLANDSERVER_DEPRECATED_VERSION_5_69(text)
+#endif
 #define KWAYLANDSERVER_DEPRECATED_VERSION_5(minor, text)      KWAYLANDSERVER_DEPRECATED_VERSION_5_##minor(text)
 #define KWAYLANDSERVER_DEPRECATED_VERSION(major, minor, text) KWAYLANDSERVER_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
+#define KWAYLANDSERVER_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWAYLANDSERVER_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
 
 #endif /* KWAYLANDSERVER_EXPORT_H */
